Index: trunk/psModules/src/camera/pmFPAfileDefine.c
===================================================================
--- trunk/psModules/src/camera/pmFPAfileDefine.c	(revision 19167)
+++ trunk/psModules/src/camera/pmFPAfileDefine.c	(revision 20400)
@@ -940,5 +940,5 @@
         psTrace ("pmFPAfile", 5, "requiring use of detrend database source\n");
         // don't free the file here: it is left on config->files
         // to be used optionally by pmFPAfileDefineFromDetDB (or others)
         if (success) {
             *success = true;
@@ -1009,4 +1009,9 @@
             return NULL;
         }
+
+	// XXX A TEST: this is a provisional fpa until we read the first header for this pmFPAfile
+	// we are going to replace it when we determine the true file.  blow this away here...
+	psFree (file->fpa);
+	file->fpa = NULL;
     }
 
@@ -940,5 +940,5 @@
         psTrace ("pmFPAfile", 5, "requiring use of detrend database source\n");
         // don't free the file here: it is left on config->files
-        // to be used optionally by pmFPAfileDefineFromDetDB (or others)
+        // to be used optionally by pmFPAfileDefineFromDetDB (or others) XXX potentially free the fpa...
         if (success) {
             *success = true;
